<div id="top"></div>

# pyforestplot

<!-- ABOUT THE PROJECT -->
<img src="https://raw.githubusercontent.com/lsys/pyforestplot/main/docs/images/under.svg" width="180"/>

<!----------------- PROJECT STATUS SHIELDS ----------------->
<table class="no-border">
  <tr>
    <td><strong>Status:</strong></td>
    <td>
      <a href="https://github.com/LSYS/pyforestplot/actions/workflows/CI.yml"><img src="https://github.com/LSYS/pyforestplot/actions/workflows/CI.yml/badge.svg?branch=main" /></a>
    </td>
    <td>
      <a href="https://app.travis-ci.com/LSYS/pyforestplot"><img src="https://app.travis-ci.com/LSYS/pyforestplot.svg?branch=main"/></a>
    </td>
    <td>
      <a href="https://codecov.io/gh/LSYS/pyforestplot" ><img src="https://codecov.io/gh/LSYS/pyforestplot/branch/main/graph/badge.svg?token=34QE11YEOQ"/></a>
    </td>
</table>
